diff --git a/modules/index.rst b/modules/index.rst
index 25f19a825d28206871b7f63225f1d0573d376198..4521313c8592ca3d57a7a91dcac7813c7a524316 100644
--- a/modules/index.rst
+++ b/modules/index.rst
@@ -77,7 +77,7 @@ Sequences and Alignments
 Graphics
 --------------------------------------------------------------------------------
 
-**Overview** :doc:`graphics intro <intro-03>`
+**Overview**: :doc:`graphics intro <intro-03>`
 
 **Main Classes**: :doc:`the scene <gfx/scene>` | :doc:`graphical entity <gfx/entity>`
 
@@ -95,19 +95,17 @@ Graphical User Interface
 Varia
 --------------------------------------------------------------------------------
 
-**Datasets:** :doc:`tabular data <table>`
+**Datasets**: :doc:`tabular data <table>`
 
-**Supported File Formats:** :doc:`structure formats<io/structure_formats>` | :doc:`sequence formats <io/sequence_formats>` | :doc:`sequence profile formats <io/sequence_profile_formats>` | :doc:`image formats <io/image_formats>`
+**Supported File Formats**: :doc:`structure formats<io/structure_formats>` | :doc:`sequence formats <io/sequence_formats>` | :doc:`sequence profile formats <io/sequence_profile_formats>` | :doc:`image formats <io/image_formats>`
 
-**Users** :doc:`Reporting a problem <users>`
+**Users**: :doc:`Reporting a problem <users>`
 
-**lDDT** :doc:`lDDT command line executable<mol/alg/lddt>`
+**lDDT**: :doc:`lDDT command line executable<mol/alg/lddt>`
 
 Extending OpenStructure
 --------------------------------------------------------------------------------
 
-**External Tools** :doc:`bindings <bindings/bindings>`
-
-**Howto:** :doc:`write new modules <newmodule>` | :doc:`integrate third-party tools <external>` | :doc:`logging <base/logging>` | :doc:`instructions for developers <contributing>`
-
+**External Tools**: :doc:`bindings <bindings/bindings>`
 
+**Howto**: :doc:`write new modules <newmodule>` | :doc:`integrate third-party tools <external>` | :doc:`logging <base/logging>` | :doc:`instructions for developers <contributing>`
diff --git a/modules/mol/alg/doc/molalg.rst b/modules/mol/alg/doc/molalg.rst
index efc8daf7bd67be079b02797858c0f68e015cc87d..4a91374fa17011c866e377799f3e762d80ec7ab6 100644
--- a/modules/mol/alg/doc/molalg.rst
+++ b/modules/mol/alg/doc/molalg.rst
@@ -4,6 +4,8 @@
 .. module:: ost.mol.alg
    :synopsis: Algorithms operating on molecular structures
 
+Local Distance Test scores (lDDT, DRMSD)
+--------------------------------------------------------------------------------
 
 .. function:: LocalDistDiffTest(model, distance_list, tolerance_list, \
                                 sequence_separation=0, \
@@ -93,9 +95,10 @@
   indexes of the two structures in the AlignmentHandle as parameters to the
   function.
 
-  BEWARE: This function uses the old implementation of the Local Distance
-  Difference Test algorithm and will give slightly different results from the
-  new one.
+  .. note::
+
+    This function uses the old implementation of the Local Distance Difference
+    Test algorithm and will give slightly different results from the new one.
 
   :param alignment: an alignment containing the sequences of the reference and
                     of the model structures, with the structures themselves
@@ -110,131 +113,177 @@
   :returns: the Local Distance Difference Test score
 
 
-.. function::  LDDTHA(model, distance_list, sequence_separation=0)
+.. function:: LDDTHA(model, distance_list, sequence_separation=0)
 
-  This function calculates the Local Distance Difference Test, using the same threshold values as the GDT-HA test 
-  (the default set of thresholds used for the lDTT score) (See previous functions). The thresholds are 0.5, 1, 2, and 4 Angstroms. 
+  This function calculates the Local Distance Difference Test, using the same
+  threshold values as the GDT-HA test (the default set of thresholds used for
+  the lDTT score) (See previous functions). The thresholds are 0.5, 1, 2, and 4
+  Angstroms.
 
-  The function only compares the input distance list to the first chain of the model structure
+  The function only compares the input distance list to the first chain of the
+  model structure
 
-  The local residue-based lDDT score values are stored in the ResidueHandles of the model passed to the 
-  function in a float property called "locallddt" 
+  The local residue-based lDDT score values are stored in the ResidueHandles of
+  the model passed to the function in a float property called "locallddt".
 
-  A sequence separation parameter can be passed to the function. If this happens, only distances between residues
-  whose separation is higher than the provided parameter are considered when computing the score.
+  A sequence separation parameter can be passed to the function. If this
+  happens, only distances between residues whose separation is higher than the
+  provided parameter are considered when computing the score.
 
   :param model: the model structure
-  :type model: :class:`~ost.mol.EntityView`
+  :type model:  :class:`~ost.mol.EntityView`
   :param distance_list: the list of distances to check for conservation
-  :type distance_list: :class:`~ost.mol.alg.GlobalRDMap`
-  :param sequence_separation: sequence separation parameter used when computing the score
+  :type distance_list:  :class:`~ost.mol.alg.GlobalRDMap`
+  :param sequence_separation: sequence separation parameter
 
   :returns: the Local Distance Difference Test score
 
 
-.. function:: DistanceRMSDTest(model, distance_list, cap_difference, sequence_separation=0,  local_drmsd_property_string="")
+.. function:: DistanceRMSDTest(model, distance_list, cap_difference, \
+                               sequence_separation=0, \
+                               local_drmsd_property_string="")
   
-  This function performs a Distance RMSD Test on a provided model, and calculates the two values that are necessary to determine 
-  the Distance RMSD Score, namely the sum of squared distance deviations and the number of distances on which the sum was computed. 
-
-  The Distance RMSD Test (or DRMSD Test) computes the deviation in the length of local contacts between a model and 
-  a reference structure and expresses it in the form of a score value. The score has an an RMSD-like form, with the deviations 
-  in the RMSD formula computed as contact distance differences. The score is open-ended, with a value of zero meaning complete 
-  agreement of local contact distances, and a positive value revealing a disagreement of magnitude proportional to the score value
-  itself. This score does not require any superposition between the model and the reference.
+  This function performs a Distance RMSD Test on a provided model, and
+  calculates the two values that are necessary to determine the Distance RMSD
+  Score, namely the sum of squared distance deviations and the number of
+  distances on which the sum was computed.
+
+  The Distance RMSD Test (or DRMSD Test) computes the deviation in the length of
+  local contacts between a model and a reference structure and expresses it in
+  the form of a score value. The score has an an RMSD-like form, with the
+  deviations in the RMSD formula computed as contact distance differences. The
+  score is open-ended, with a value of zero meaning complete agreement of local
+  contact distances, and a positive value revealing a disagreement of magnitude
+  proportional to the score value itself. This score does not require any
+  superposition between the model and the reference.
   
-  This function processes a list of distances provided by the user, together with their length in the reference structure. 
-  For each distance that is found in the model, its difference with the reference length is computed and used as deviation term in the RMSD-like 
-  formula.  When a distance is not present in the model because one or both the atoms are missing, a default deviation value provided by the 
-  user is used. 
-
-  The function only processes distances between atoms that do not belong to the same residue, and considers only standard residues 
-  in the first chain of the model. For residues with symmetric sidechains (GLU, ASP, ARG, VAL, PHE, TYR), the 
-  naming of the atoms is ambiguous. For these residues, the function computes the Distance RMSD Test score that each 
-  naming convention would generate when considering all non-ambiguous surrounding atoms.
-  The solution that gives the lower score is then picked to compute the final Distance RMSD Score for the whole model.
+  This function processes a list of distances provided by the user, together
+  with their length in the reference structure. For each distance that is found
+  in the model, its difference with the reference length is computed and used as
+  deviation term in the RMSD-like formula.When a distance is not present in the
+  model because one or both the atoms are missing, a default deviation value
+  provided by the user is used.
+
+  The function only processes distances between atoms that do not belong to the
+  same residue, and considers only standard residues in the first chain of the
+  model. For residues with symmetric sidechains (GLU, ASP, ARG, VAL, PHE, TYR),
+  the naming of the atoms is ambiguous. For these residues, the function
+  computes the Distance RMSD Test score that each naming convention would
+  generate when considering all non-ambiguous surrounding atoms. The solution
+  that gives the lower score is then picked to compute the final Distance RMSD
+  Score for the whole model.
   
-  A sequence separation parameter can be passed to the function. If this happens, only distances between residues
-  whose separation is higher than the provided parameter are considered when computing the score
-
-  If a string is passed as last parameter to the function, the function computes the Distance RMSD Score
-  for each residue and saves it as a float property in the ResidueHandle, with the passed string
-  as property name. Additionally, the actual sum of squared deviations and the number of distances on which it was computed 
-  are stored as properties in the ResidueHandle. The property names are respectively <passed string>_sum (a float property) and 
-  <passed string>_count (an integer property)
+  A sequence separation parameter can be passed to the function. If this
+  happens, only distances between residues whose separation is higher than the
+  provided parameter are considered when computing the score.
+
+  If a string is passed as last parameter to the function, the function computes
+  the Distance RMSD Score for each residue and saves it as a float property in
+  the ResidueHandle, with the passed string as property name. Additionally, the
+  actual sum of squared deviations and the number of distances on which it was
+  computed are stored as properties in the ResidueHandle. The property names are
+  respectively <passed string>_sum (a float property) and <passed string>_count
+  (an integer property).
 
   :param model: the model structure
-  :type model: :class:`~ost.mol.EntityView`
-  :param distance_list: the list of distances to check.  
-  :type distance_list: :class:`~ost.mol.alg.GlobalRDMap`. This class stores two length values for each distance. Only the first is used by this function as
-                      reference length. The second is ignored.
-  :param cap_difference: a default deviation value to be used when a distance is not found in the model
-  :param sequence_separation: sequence separation parameter used when computing the score
-  :param local_ldt_property_string: the base name for the ResidueHandle properties that store the local scores
+  :type model:  :class:`~ost.mol.EntityView`
+  :param distance_list: the list of distances to check (here we only use the
+                        first of the two distance values stored, the second
+                        is ignored)
+  :type distance_list:  :class:`~ost.mol.alg.GlobalRDMap`
+  :param cap_difference: a default deviation value to be used when a distance is
+                         not found in the model
+  :param sequence_separation: sequence separation parameter
+  :param local_ldt_property_string: the base name for the ResidueHandle
+                                    properties that store the local scores
 
-  :returns: a tuple containing the sum of squared distance deviations, and the number of distances on which it was computed.
+  :returns: a tuple containing the sum of squared distance deviations, and the
+            number of distances on which it was computed.
 
 
-.. function::  DRMSD(model, distance_list, cap_difference, sequence_separation=0)
+.. function:: DRMSD(model, distance_list, cap_difference, sequence_separation=0)
 
-  This function calculates the Distance RMSD Test score (see previous function).
+  This function calculates the Distance RMSD Test score (see
+  :func:`DistanceRMSDTest`).
   
-  The function only considder distances between atoms not belonging to the same residue, and only compares the input distance list to the first
-   chain of the model structure. It requires, in addition to the model and the list themselves, a default deviation value to be used in the DRMSD
-   Test when a distance is not found in the model.  
+  The function only considers distances between atoms not belonging to the same
+  residue, and only compares the input distance list to the first chain of the
+  model structure. It requires, in addition to the model and the list
+  themselves, a default deviation value to be used in the DRMSD Test when a
+  distance is not found in the model.
 
-  The local Local Distance Difference Test score values are stored in the ResidueHandles of the model passed to the 
-  function in a float property called "localdrmsd" 
+  The local Local Distance Difference Test score values are stored in the
+  ResidueHandles of the model passed to the function in a float property called
+  "localdrmsd".
 
-  A sequence separation parameter can be passed to the function. If this happens, only distances between residues
-  whose separation is higher than the provided parameter are considered when computing the score
+  A sequence separation parameter can be passed to the function. If this
+  happens, only distances between residues whose separation is higher than the
+  provided parameter are considered when computing the score.
 
   :param model: the model structure
-  :type model: :class:`~ost.mol.EntityView`
-  :param distance_list: the list of distances to check for conservation
-  :type distance_list: :class:`~ost.mol.alg.GlobalRDMap`. This class stores two length values for each distance. Only the first is used by this function as
-                      reference length. The second is ignored.
-  :param sequence_separation: sequence separation parameter used when computing the score
-  :param cap_difference: a default deviation value to be used when a distance is not found in the model
+  :type model:  :class:`~ost.mol.EntityView`
+  :param distance_list: the list of distances as in :func:`DistanceRMSDTest`
+  :type distance_list: :class:`~ost.mol.alg.GlobalRDMap`
+  :param cap_difference: a default deviation value to be used when a distance is
+                         not found in the model
+  :param sequence_separation: sequence separation parameter
   :returns: the Distance RMSD Test score
 
 
 .. function:: CreateDistanceList(reference, radius)
-.. function:: CreateDistanceListFromMultipleReferences(reference_list, tolerance_list, sequence_separation, radius)
-
-  Both these functions create lists of distances to be checked during a Local Distance Difference Test
-  (see description of the functions above). 
-
-  Both functions process only standard residues present in the first chain of the reference structures.
-
-  The only difference between the two functions is that one takes a single reference structure and the other
-  a list of reference structures. The structures in the list have to be properly prepared before being passed 
-  to the function. Corresponding residues in the structures must have the same residue number, the same chain name,
-  etc. Gaps are allowed and automatically dealt with: if information about a distance is present in at least one of
-  the structures, it will be considered.  
-
-  If a distance between two atoms is shorter than the inclusion radius in all structures in which the two atoms are
-  present, it is included in the list. However, if the distance is longer than the inclusion radius in at least
-  one of the structures, it is not considered to be a local interaction and is excluded from the list.
-
-  The multiple-reference function takes care of residues with ambiguous symmetric sidechains. To decide which naming
-  convention to use, the function computes a Local Distance Difference Test score for  each reference against the
-  first reference structure in the list, using only non ambiguously-named atoms. It picks then the naming convention
-  that gives the highest score, guaranteeing that all references are processed with the correct atom names.
-
-  The cutoff list that will later be used to compute the Local Distance Difference Test score and the sequence
-  separation parameter must be passed to the multi-reference function. These parameters do not influence the output
-  distance list, which always includes all distances within the provided radius (to make it consistent with the
-  single-reference corresponding function). However, the parameters are used when dealing with the naming convention
-  of residues with ambiguous nomenclature.
+              CreateDistanceListFromMultipleReferences(reference_list, \
+                                                       tolerance_list, \
+                                                       sequence_separation, \
+                                                       radius)
+
+  Both these functions create lists of distances to be checked during a Local
+  Distance Difference Test (see description of the functions above).
+
+  .. note::
+
+    These functions process only standard residues present in the first chain of
+    the reference structures.
+
+  The only difference between the two functions is that one takes a single
+  reference structure and the other a list of reference structures. The
+  structures in the list have to be properly prepared before being passed to the
+  function. Corresponding residues in the structures must have the same residue
+  number, the same chain name, etc. Gaps are allowed and automatically dealt
+  with: if information about a distance is present in at least one of the
+  structures, it will be considered.
+
+  If a distance between two atoms is shorter than the inclusion radius in all
+  structures in which the two atoms are present, it is included in the list.
+  However, if the distance is longer than the inclusion radius in at least one
+  of the structures, it is not considered to be a local interaction and is
+  excluded from the list.
+
+  The multiple-reference function takes care of residues with ambiguous
+  symmetric sidechains. To decide which naming convention to use, the function
+  computes a Local Distance Difference Test score foreach reference against the
+  first reference structure in the list, using only non ambiguously-named atoms.
+  It picks then the naming convention that gives the highest score, guaranteeing
+  that all references are processed with the correct atom names.
+
+  The cutoff list that will later be used to compute the Local Distance
+  Difference Test score and the sequence separation parameter must be passed to
+  the multi-reference function. These parameters do not influence the output
+  distance list, which always includes all distances within the provided radius
+  (to make it consistent with the single-reference corresponding function).
+  However, the parameters are used when dealing with the naming convention of
+  residues with ambiguous nomenclature.
 
   :param reference: a reference structure from which distances are derived
-  :type reference: :class:`~ost.mol.EntityView`
-  :param reference_list: a list of  of reference structures from which distances are derived
-  :type reference_list: list of :class:`~ost.mol.EntityView`
-  :param tolerance_list: a list of thresholds used to determine distance conservation when computing the LDDT score
-  :param sequence_separation: sequence separation parameter used when computing the LDDT score
-  :param radius: inclusion radius (in Angstroms) used to determine the distances included in the list
+  :type reference:  :class:`~ost.mol.EntityView`
+  :param reference_list: a list of reference structures from which distances are
+                         derived
+  :type reference_list:  list of :class:`~ost.mol.EntityView`
+  :param tolerance_list: a list of thresholds used to determine distance
+                         conservation when computing the lDDT score
+  :param sequence_separation: sequence separation parameter used when computing
+                              the lDDT score
+  :param radius: inclusion radius (in Angstroms) used to determine the distances
+                 included in the list
   
   :returns: :class:`~ost.mol.alg.GlobalRDMap`
 
@@ -247,10 +296,12 @@
     
     Creates an UniqueAtomIdentifier object starting from relevant atom information
 
-    :param chain: a string containing the name of the chain to which the atom belongs
-    :param residue_number: the number of the residue to which the atom belongs 
-    :type residue_number: :class:`~ost.mol.ResNum`
-    :param residue_name: a string containing the name of the residue to which the atom belongs
+    :param chain: a string containing the name of the chain to which the atom
+                  belongs
+    :param residue_number: the number of the residue to which the atom belongs
+    :type residue_number:  :class:`~ost.mol.ResNum`
+    :param residue_name: a string containing the name of the residue to which
+                         the atom belongs
     :param atom_name: a string containing the name of the atom
 
   .. method:: GetChainName() 
@@ -259,7 +310,8 @@
 
   .. method:: GetResNum() 
 
-    Returns the number of the residue the atom belongs to, as a :class:`~ost.mol.ResNum` object
+    Returns the number of the residue the atom belongs to, as a
+    :class:`~ost.mol.ResNum` object
 
   .. method:: GetResidueName()
     
@@ -271,53 +323,36 @@
 
   .. method:: GetQualifiedAtomName()
 
-     Returns the qualified name of the atom (the chain name, followed by a unique residue identifier and the atom name. For example:  “A.GLY2.CA”)
+     Returns the qualified name of the atom (the chain name, followed by a
+     unique residue identifier and the atom name. For example: "A.GLY2.CA")
 
 
 .. class:: ResidueRDMap
 
-  Dictionary-like object containing the a list of distances that originate from the a single residue residue, to
-  check during a run of the Local Distance Difference Test algorithm 
-
+  Dictionary-like object containing the list of interatomic distances that
+  originate from a single residue to be checked during a run of the Local
+  Distance Difference Test algorithm
+  (key = pair of :class:`UniqueAtomIdentifier`, value = pair of floats)
 
 .. class:: GlobalRDMap
 
-  Dictionary-like object containing all the :class:`~ost.mol.alg.ResidueRDMap` objects related to residues
-  of a single structure
+  Dictionary-like object containing all the :class:`~ost.mol.alg.ResidueRDMap` objects related to residues of a single structure
+  (key = :class:`~ost.mol.ResNum`, value = :class:`ResidueRDMap`)
 
   
 .. function:: PrintResidueRDMap(residue_distance_list)
 
-  Prints to standard output all the distances contained in a :class:`~ost.mol.alg.ResidueRDMap` object 
+  Prints to standard output all the distances contained in a
+  :class:`~ost.mol.alg.ResidueRDMap` object
 
 
 .. function:: PrintGlobalRDMap(global_distance_list)
 
-  Prints to standard output all the distances contained in each of the :class:`~ost.mol.alg.ResidueRDMap` objects that
-  make up a :class:`~ost.mol.alg.GlobalRDMap` object
+  Prints to standard output all the distances contained in each of the
+  :class:`~ost.mol.alg.ResidueRDMap` objects that make up a
+  :class:`~ost.mol.alg.GlobalRDMap` object.
 
 
-.. function:: Swappable(residue_name,atom_name)
-
-  This function checks if an atom in a residue has a symmetry equivalent. It returns true if the atom belongs to a residue with a symmetric side-chain
-   and a symmetry equivalent atom exists, otherwise it returns false. 
-
-  :param residue_name: a string containing the name of the residue to which the atom belongs
-  :param atom_name: a string containing the name of the atom
-  
-  :returns: True if the atom has a symmetry equivalent, false otherwise
-
-
-.. function:: SwappedName(atom_name)
-  
-   If the atom does belongs to a residue with a symmetric side-chain and if the atom has a symmetry
-   equivalent, the function returns the name of the symmetry equivalent atom, otherwise it returns the name of the original
-   atom
-
-  :param atom_name: a string containing the name of the atom
-  
-  :returns: A string containing the same of the symmetry equivalent atom if the input atom has one, otherwise the name of the input atom itself.
-
 
 
 .. _steric-clashes:
@@ -330,19 +365,22 @@ The following function detects steric clashes in atomic structures. Two atoms ar
 
 .. function:: FilterClashes(entity, clashing_distances, always_remove_bb=False)
 
-  This function filters out residues with non-bonded clashing atoms. If the clashing atom 
-  is a backbone atom, the complete residue is removed from the structure, if the atom is part of 
-  the sidechain, only the sidechain atoms are removed. This behavior is changed 
-  by the always_remove_bb flag: when the flag is set to True the whole residue is removed even if
-  a clash is just detected in the side-chain.
+  This function filters out residues with non-bonded clashing atoms. If the
+  clashing atom is a backbone atom, the complete residue is removed from the
+  structure, if the atom is part of the sidechain, only the sidechain atoms are
+  removed. This behavior is changed  by the *always_remove_bb* flag: when the
+  flag is set to True the whole residue is removed even if a clash is just
+  detected in the side-chain.
 
-  The function returns a view containing all elements (residues, atoms) that have not been removed from the 
-  input structure, plus a :class:`~ost.mol.alg.ClashingInfo` object containing information about the 
+  The function returns a view containing all elements (residues, atoms) that
+  have not been removed from the input structure, plus a
+  :class:`~ost.mol.alg.ClashingInfo` object containing information about the
   detected clashes.
   
-  Two atoms are defined as clashing if their distance is shorter than the reference distance minus a tolerance
-  threshold. The information about the clashing distances and the tolerance thresholds for all possible pairs of 
-  atoms is passed to the function as a parameter
+  Two atoms are defined as clashing if their distance is shorter than the
+  reference distance minus a tolerance threshold. The information about the
+  clashing distances and the tolerance thresholds for all possible pairs of
+  atoms is passed to the function as a parameter.
 
   Hydrogen and deuterium atoms are ignored by this function.
   
@@ -350,22 +388,36 @@ The following function detects steric clashes in atomic structures. Two atoms ar
   :type entity: :class:`~ost.mol.EntityView` or :class:`~ost.mol.EntityHandle`
   :param clashing_distances: information about the clashing distances
   :type clashing_distances: :class:`~ost.mol.alg.ClashingDistances`
-  :param always_remove_bb: if set to True, the whole residue is removed even if the clash happens in the side-chain
+  :param always_remove_bb: if set to True, the whole residue is removed even if
+                           the clash happens in the side-chain
+  :type always_remove_bb:  :class:`bool`
 
-  :returns: A tuple of two elements: The filtered :class:`~ost.mol.EntityView`, and a :class:`~ost.mol.alg.ClashingInfo` object
+  :returns: A tuple of two elements: The filtered :class:`~ost.mol.EntityView`,
+            and a :class:`~ost.mol.alg.ClashingInfo` object
 
 
-.. function:: CheckStereoChemistry(entity,bond_stats,angle_stats,bond_tolerance,angle_tolerance,always_remove_bb=False)
+.. function:: CheckStereoChemistry(entity, bond_stats, angle_stats, \
+                                   bond_tolerance, angle_tolerance, \
+                                   always_remove_bb=False)
 
-  This function filters out residues with severe stereo-chemical violations. If the violation 
-  involves a backbone atom, the complete residue is removed from the structure, if it involves an atom that is 
-  part of the sidechain, only the sidechain is removed. This behavior is changed 
-  by the always_remove_bb flag: when the flag is set to True the whole residue is removed even if
-  a violation is just detected in the side-chain
+  This function filters out residues with severe stereo-chemical violations. If
+  the violation involves a backbone atom, the complete residue is removed from
+  the structure, if it involves an atom that is part of the sidechain, only the
+  sidechain is removed. This behavior is changed  by the *always_remove_bb*
+  flag: when the flag is set to True the whole residue is removed even if a
+  violation is just detected in the side-chain.
 
-  The function returns a view containing all elements (residues, atoms) that have not been removed from the input structure, plus a :class:`~ost.mol.alg.StereoChemistryInfo` object containing information about the detected stereo-chemical violations.
+  The function returns a view containing all elements (residues, atoms) that
+  have not been removed from the input structure, plus a
+  :class:`~ost.mol.alg.StereoChemistryInfo` object containing information about
+  the detected stereo-chemical violations.
     
-  A violation is defined as a bond length that lies outside of the range: [mean_length-std_dev*bond_tolerance <-> meanlength+std_dev*bond_tolerance] or an angle width lying outside of the range [mean_width-std_dev*angle_tolerance <-> mean_width+std_dev*angle_tolerance ]. The information about the mean lengths and widths and the corresponding standard deviations is passed to the function using two parameters.
+  A violation is defined as a bond length that lies outside of the range:
+  [mean_length-std_dev*bond_tolerance, mean_length+std_dev*bond_tolerance] or an
+  angle width outside of the range [mean_width-std_dev*angle_tolerance,
+  mean_width+std_dev*angle_tolerance ]. The information about the mean lengths
+  and widths and the corresponding standard deviations is passed to the function
+  using two parameters.
 
   Hydrogen and deuterium atoms are ignored by this function.
 
@@ -376,100 +428,106 @@ The following function detects steric clashes in atomic structures. Two atoms ar
   :param angle_stats: statistics about angle widths
   :type angle_stats: :class:`~ost.mol.alg.StereoChemicalParams`
   :param bond_tolerance: tolerance for bond lengths (in standard deviations)
-  :param angle_tolerance: tolerance for angle widths (in standard deviations)£
-  :param always_remove_bb: if set to True, the whole residue is removed even if a violation in just detected in the side-chain
+  :type bond_tolerance:  :class:`float`
+  :param angle_tolerance: tolerance for angle widths (in standard deviations)
+  :type angle_tolerance:  :class:`float`
+  :param always_remove_bb: if set to True, the whole residue is removed even if
+                           the clash happens in the side-chain
+  :type always_remove_bb:  :class:`bool`
 
   :returns: A tuple of two elements: The filtered :class:`~ost.mol.EntityView`, and a :class:`~ost.mol.alg.StereoChemistryInfo` object
 
 
 .. class:: ClashingInfo
 
-  This object is returned by the FilterClashes function, and contains information about the clashes detected by the function. 
+  This object is returned by the :func:`FilterClashes` function, and contains
+  information about the clashes detected by the function.
 
   .. method:: GetClashCount()
 
-     This method returns the number of clashes between non-bonded atoms detected in the input structure
+    :return: number of clashes between non-bonded atoms detected in the
+             input structure
 
   .. method:: GetAverageOffset()
 
-     This methods returns a value in Angstroms representing the average offset by which clashing atoms lie closer than the minimum acceptable distance (which of course differs for each possible pair of elements)
-
-     :returns: the average offset, in Angstroms
+    :return: a value in Angstroms representing the average offset by which
+             clashing atoms lie closer than the minimum acceptable distance
+             (which of course differs for each possible pair of elements)
 
   .. method:: GetClashList()
 
-     Returns the list of detected inter-atomic clashes
-
-     :returns: a list of :class:`~ost.mol.alg.ClashEvent` objects
+    :return: list of detected inter-atomic clashes
+    :rtype:  :class:`list` of :class:`ClashEvent`
 
 
 .. class:: ClashEvent
 
-  This object contains all the information relative to a single clash detected by the FilterClashes function
+  This object contains all the information relative to a single clash detected
+  by the :func:`FilterClashes` function
 
   .. method:: GetFirstAtom()
-  .. method:: GetSecondAtom()
+              GetSecondAtom()
 
-     These two methods return the two atoms which clash
-
-     :returns: :class:`~ost.mol.alg.UniqueAtomIdentifier`
+    :return: atoms which clash
+    :rtype:  :class:`~ost.mol.alg.UniqueAtomIdentifier`
 
   .. method:: GetModelDistance()
 
-     This method returns the distance between the two clashing atoms as observed in the model
-
-     :returns: the distance in Angstroms between the two atoms
+    :return: distance (in Angstroms) between the two clashing atoms as observed
+             in the model
 
   .. method:: GetAdjustedReferenceDistance()
 
-     This method returns the minimum acceptable distance between the two atoms involved in the clash, as defined in the :class:`~ost.mol.alg.ClashingDistances` class
-
-     :returns: the minimum acceptable distance in Angstroms
+    :return: minimum acceptable distance (in Angstroms) between the two atoms
+             involved in the clash, as defined in :class:`ClashingDistances`
 
 
 .. class:: StereoChemistryInfo
 
-  This object is returned by the CheckStereoChemistry function, and contains information about bond lengths and planar angle widths in the structure that diverge from the parameters tabulated by Engh and Huber in the International Tables of Crystallography. Only elements that diverge from the tabulated value by a minimum  number of standard deviations (defined when the CheckStereoChemistry function is called) are reported.
+  This object is returned by the :func:`CheckStereoChemistry` function, and
+  contains information about bond lengths and planar angle widths in the
+  structure that diverge from the parameters tabulated by Engh and Huber in the
+  International Tables of Crystallography. Only elements that diverge from the
+  tabulated value by a minimumnumber of standard deviations (defined when the
+  CheckStereoChemistry function is called) are reported.
 
   .. method:: GetBadBondCount()
 
-     This method returns the number of bonds where a serious violation was detected
+    :return: number of bonds where a serious violation was detected
 
   .. method:: GetBondCount()
 
-     This method returns the total number of bonds in the structure checked by the CheckStereoChemistry function
+    :return: total number of bonds in the structure checked by the
+             CheckStereoChemistry function
 
   .. method:: GetAvgZscoreBonds()
 
-     This method returns the average z-score of all the bond lengths in the structure, computed using Engh and Huber's mean and standard deviation values.
-
-     :returns: The average z-score of bond lengths
+    :return: average z-score of all the bond lengths in the structure, computed
+             using Engh and Huber's mean and standard deviation values
 
-  .. method:: GetBadAngleCount()  
+  .. method:: GetBadAngleCount()
 
-     This method returns the number of planar angles where a serious violation was detected
+    :return: number of planar angles where a serious violation was detected
 
   .. method:: GetAngleCount()
 
-     This method returns the total number of planar angles in the structure checked by the CheckStereoChemistry function
+    :return: total number of planar angles in the structure checked by the
+             CheckStereoChemistry function
 
   .. method:: GetAvgZscoreAngles()
 
-     This method returns the average z-score of all the planar angle widths, computed using Engh and Huber's mean and standard deviation values.
-
-     :returns: The average z-score of planar angle widths
+    :return: average z-score of all the planar angle widths, computed using Engh
+             and Huber's mean and standard deviation values.
 
   .. method:: GetBondViolationList()
 
-     Returns the list of bond length violations detected in the structure
-
-     :returns: a list of :class:`~ost.mol.alg.StereoChemicalBondViolation` objects
+     :return: list of bond length violations detected in the structure
+     :rtype:  :class:`list` of :class:`~ost.mol.alg.StereoChemicalBondViolation`
 
   .. method:: GetAngleViolationList()
 
-     Returns the list of angle width violations detected in the structure
-
-     :returns: a list of :class:`~ost.mol.alg.StereoChemicalAngleViolation` objects
+     :return: list of angle width violations detected in the structure
+     :rtype: :class:`list` of :class:`~ost.mol.alg.StereoChemicalAngleViolation`
 
 
 .. class:: StereoChemicalBondViolation
@@ -477,28 +535,21 @@ The following function detects steric clashes in atomic structures. Two atoms ar
   This object contains all the information relative to a single detected violation of stereo-chemical parameters in a bond length
 
   .. method:: GetFirstAtom()
+              GetSecondAtom()
 
-     Returns the first atom of the bond
-
-     :returns: :class:`~ost.mol.alg.UniqueAtomIdentifier`
-
-  .. method:: GetSecondAtom()
-
-     Returns the first atom of the bond
-
-     :returns: :class:`~ost.mol.alg.UniqueAtomIdentifier`
+    :return: first / second atom of the bond
+    :rtype:  :class:`~ost.mol.alg.UniqueAtomIdentifier`
 
   .. method:: GetBondLength()
 
-     Returns the length of the bond as observed in the model
-
-     :returns: the bond length in Angstroms
+    :return: length of the bond (in Angstroms) as observed in the model
 
   .. method:: GetAllowedRange()
 
-     Returns the allowed range of bond lengths, according to the Engh and Huber's tabulated parameters and the tolerance threshold used when CheckStereoChemistry function was called
-
-     :returns: a tuple containing the minimum and maximum allowed bond lengths in Angstroms
+    :return: allowed range of bond lengths (in Angstroms), according to Engh and
+             Huber's tabulated parameters and the tolerance threshold used when
+             the :func:`CheckStereoChemistry` function was called
+    :rtype:  :class:`tuple` (minimum and maximum)
 
 
 .. class:: StereoChemicalAngleViolation
@@ -506,34 +557,22 @@ The following function detects steric clashes in atomic structures. Two atoms ar
   This object contains all the information relative to a single detected violation of stereo-chemical parameters in a planar angle width
 
   .. method:: GetFirstAtom()
+              GetSecondAtom()
+              GetThirdAtom()
 
-     Returns the first atom that defines the planar angle 
-
-     :returns: :class:`~ost.mol.alg.UniqueAtomIndentifier`
-
-  .. method:: GetSecondAtom()
-
-     Returns the vertex atom of the planar angle
-
-     :returns: :class:`~ost.mol.alg.UniqueAtomIdentifier`
-
-  .. method:: GetThirdAtom()
-
-     Returns the third atom that defines the planar angle
-
-     :returns: :class:`~ost.mol.alg.UniqueAtomIdentifier`
+    :return: first / second (vertex) / third atom that defines the planar angle
+    :rtype:  :class:`UniqueAtomIdentifier`
 
   .. method:: GetAngleWidth()
 
-     Returns the width of the planar angle as observed in the model
-
-     :returns: the angle width in degrees
+    :return: width of the planar angle (in degrees) as observed in the model
 
   .. method:: GetAllowedRange()
 
-     Returns the allowed range of angle widths, according to the Engh and Huber's tabulated parameters and the tolerance threshold used when the CheckStereoChemistry function was called
-
-     :returns: a tuple containing the minimum and maximum allowed angle widths in degrees
+    :return: allowed range of angle widths (in degrees), according to Engh and
+             Huber's tabulated parameters and the tolerance threshold used when
+             the :func:`CheckStereoChemistry` function was called
+    :rtype:  :class:`tuple` (minimum and maximum)
 
 
 .. class:: ClashingDistances
@@ -544,7 +583,7 @@ The following function detects steric clashes in atomic structures. Two atoms ar
 
     Creates an empty distance list
 
-  .. method:: SetClashingDistance(ele1,ele2, clash_distance, tolerance)
+  .. method:: SetClashingDistance(ele1, ele2, clash_distance, tolerance)
 
     Adds or replaces an entry in the list
 
@@ -553,31 +592,29 @@ The following function detects steric clashes in atomic structures. Two atoms ar
     :param clash_distance: minimum clashing distance (in Angstroms)
     :param tolerance: tolerance threshold (in Angstroms)
 
-  .. method:: GetClashingDistance()
-
-     Recovers a reference distance and a tolerance threshold from the list
+  .. method:: GetClashingDistance(ele1, ele2)
 
+    :return: reference distance and a tolerance threshold (both in Angstroms)
+             for two elements
+    :rtype:  :class:`tuple` (minimum clashing distance, tolerance threshold)
     :param ele1: string containing the first element's name 
     :param ele2: string containing the second element's name 
 
-    :returns: a tuple containing the minimum clashing distance and the tolerance threshold
-
-  .. method:: GetAdjustedClashingDistance()
-
-     Recovers a reference distance from the list, already adjusted by the tolerance threshold
+  .. method:: GetAdjustedClashingDistance(ele1, ele2)
 
+    :return: reference distance (in Angstroms) for two elements, already
+             adjusted by the tolerance threshold
     :param ele1: string containing the first element's name
     :param ele2: string containing the second element's name
 
-    :returns: the adjusted minimum clashing distance
-
-  .. method::  GetMaxAdjustedDistance()
+  .. method:: GetMaxAdjustedDistance()
  
-    Returns the longest clashing distance in the list, after adjustment with tolerance threshold    
+    :return: longest clashing distance (in Angstroms) in the list, after
+             adjustment with tolerance threshold
 
   .. method:: IsEmpty()
 
-    Returns True if the list is empty (i.e. in an invalid, useless state)
+    :return: True if the list is empty (i.e. in an invalid, useless state)
  
   .. method:: PrintAllDistances()
 
@@ -586,8 +623,9 @@ The following function detects steric clashes in atomic structures. Two atoms ar
 
 .. class:: StereoChemicalParams
 
-  Object containing stereo-chemical information about bonds and angles. For each item (bond or angle
-  in a specific residue), stores the mean and standard deviation 
+  Object containing stereo-chemical information about bonds and angles. For each
+  item (bond or angle in a specific residue), stores the mean and standard
+  deviation
 
   .. method:: StereoChemicalParams()
 
@@ -597,86 +635,93 @@ The following function detects steric clashes in atomic structures. Two atoms ar
 
     Adds or replaces an entry in the list
 
-    :param item: string defining a bond (format: X-Y) or an angle (format:X-Y-Z), where X,Y an Z are atom names 
-    :param residue: string containing the residue type the information pertains to 
-    :param mean: mean bond length or angle width
-    :param standard_dev: standard deviation of the bond length or of the angle width
-
-  .. method GetParam(item,residue)
-
-     Recovers an entry from the list, 
+    :param item: string defining a bond (format: X-Y) or an angle (format:
+                 X-Y-Z), where X,Y an Z are atom names
+    :param residue: string containing the residue type for this entry
+    :param mean: mean bond length (in Angstroms) or angle width (in degrees)
+    :param standard_dev: standard deviation of the bond length (in Angstroms)
+                         or of the angle width (in degrees)
 
-    :param item: string defining a bond (format: X-Y) or an angle (format:X-Y-Z), where X,Y an Z are atom names 
-    :param residue: string containing the residue type the item information pertains to 
+  .. method GetParam(item, residue)
 
-    :returns: a tuple containing the mean length or width and the standard deviation
+    :return: entry from the list as set in :meth:`SetParam`
+    :rtype:  :class:`tuple` (mean, standard deviation)
+    :param item: string as used in :meth:`SetParam`
+    :param residue: string as used in :meth:`SetParam`
 
-  .. method ContainsParam(item,residue)
+  .. method ContainsParam(item, residue)
 
-    Checks if a specific entry is present in the list 
-
-    :param item: string defining a bond (format: X-Y) or an angle (format:X-Y-Z), where X,Y an Z are atom names 
-    :param residue: string containing the residue type the information pertains to 
-
-    :returns: True if the list contains an entry corresponding to the correct item and residue, False if it does not
+    :return: True if a specific entry is present in the list, False if not
+    :param item: string as used in :meth:`SetParam`
+    :param residue: string as used in :meth:`SetParam`
 
   .. method:: IsEmpty()
 
-    Returns True if the list is empty (i.e. in an invalid, useless state)
+    :return: True if the list is empty (i.e. in an invalid, useless state)
  
   .. method:: PrintAllParameters()
 
-    Prints all distances in the list to standard output  
+    Prints all entries in the list to standard output  
 
 
 .. function:: FillClashingDistances(file_content)
-.. function:: FillBondStereoChemicalParams(file_content)
-.. function:: FillAngleStereoChemicalParams(file_content)
+              FillBondStereoChemicalParams(file_content)
+              FillAngleStereoChemicalParams(file_content)
 
-  These three functions fill a list of reference clashing distances, a list of stereo-chemical parameters for 
-  bonds and a list of stereo-chemical parameters for angles, respectively, starting from a the content of 
-  parameter file. The content of the file is passed to the function as a list of strings, each containing
-  a line from the parameter file
+  These three functions fill a list of reference clashing distances, a list of
+  stereo-chemical parameters for bonds and a list of stereo-chemical parameters
+  for angles, respectively, starting from the content of a parameter file.
 
-  :returns: :class:`~ost.mol.alg.ClashingDistances` and :class:`~ost.mol.alg.StereoChemicalParams` respectively
+  :param file_content: list of lines from the parameter file
+  :type file_content:  :class:`list` of :class:`str`
+
+  :rtype: :class:`~ost.mol.alg.ClashingDistances` or
+          :class:`~ost.mol.alg.StereoChemicalParams`
 
 
 .. function:: FillClashingDistancesFromFile(filename)
-.. function:: FillBondStereoChemicalParamsFromFile(filename)
-.. function:: FillAngleStereoChemicalParamsFromFile(filename)
+              FillBondStereoChemicalParamsFromFile(filename)
+              FillAngleStereoChemicalParamsFromFile(filename)
+
+  These three functions fill a list of reference clashing distances, a list of
+  stereo-chemical parameters for bonds and a list of stereo-chemical parameters
+  for angles, respectively, starting from a file path.
 
-  These three functions fill a list of reference clashing distances, a list of stereo-chemical parameters for 
-  bonds and a list of stereo-chemical parameters for angles, respectively, starting from a file. The filename 
-  passed to the function can be a full path.
+  :param filename: path to parameter file
+  :type filename:  :class:`str`
 
-  :returns: :class:`~ost.mol.alg.ClashingDistances` and :class:`~ost.mol.alg.StereoChemicalParams` respectively
+  :rtype: :class:`~ost.mol.alg.ClashingDistances` or
+          :class:`~ost.mol.alg.StereoChemicalParams`
 
 
 .. function:: DefaultClashingDistances()
-.. function:: DefaultBondStereoChemicalParams()
-.. function:: DefaultAngleStereoChemicalParams()
+              DefaultBondStereoChemicalParams()
+              DefaultAngleStereoChemicalParams()
 
-  These three functions fill a list of reference clashing distances, a list of stereo-chemical parameters for 
-  bonds and a list of stereo-chemical parameters for angles, respectively, using the default parameter file
-  distributed with OpenStructure.
+  These three functions fill a list of reference clashing distances, a list of
+  stereo-chemical parameters for bonds and a list of stereo-chemical parameters
+  for angles, respectively, using the default parameter files distributed with
+  OpenStructure.
 
-  :returns: :class:`~ost.mol.alg.ClashingDistances` and :class:`~ost.mol.alg.StereoChemicalParams` respectively
+  :rtype: :class:`~ost.mol.alg.ClashingDistances` or
+          :class:`~ost.mol.alg.StereoChemicalParams`
 
 
-.. function:: ResidueNamesMatch(probe,reference)
+.. function:: ResidueNamesMatch(probe, reference)
 
-  The function requires a reference structure and a probe structure. The function checks that all the 
-  residues in the reference structure that appear in the probe structure (i.e., that have the 
-  same ResNum) are of the same residue type. Chains are comapred by order, not by chain name 
-  (i.e.: the first chain of the reference will be compared with the first chain of the probe 
+  The function requires a reference structure and a probe structure. The
+  function checks that all the residues in the reference structure that appear
+  in the probe structure (i.e., that have the same ResNum) are of the same
+  residue type. Chains are comapred by order, not by chain name (i.e.: the first
+  chain of the reference will be compared with the first chain of the probe
   structure, etc.)
 
   :param probe: the structure to test
-  :type probe: :class:`~ost.mol.EntityView`
+  :type probe:  :class:`~ost.mol.EntityView`
   :param reference: the reference structure
-  :type reference: :class:`~ost.mol.EntityView`
+  :type reference:  :class:`~ost.mol.EntityView`
 
-  :returns: true if the residue names are the same, false otherwise
+  :return: True if the residue names are the same, False otherwise
 
 
 Superposing structures
@@ -792,16 +837,16 @@ Superposing structures
 Algorithms on Structures
 --------------------------------------------------------------------------------
 
-.. method:: Accessibility(ent, [probe_radius=1.4, include_hydrogens=False,\
+.. method:: Accessibility(ent, probe_radius=1.4, include_hydrogens=False,\
                           include_hetatm=False, include_water=False,\
                           oligo_mode=False, selection="", asa_abs="asaAbs",\
-                          asa_rel="asaRel", asa_atom="asaAtom"])
+                          asa_rel="asaRel", asa_atom="asaAtom")
             
   Calculates the accesssible surface area for ever atom in *ent* according to 
   Lee & Richards by "rolling" a probe with given *probe_radius* over the atoms.
 
   :param ent:           Entity on which to calculate the surface
-  :type ent:            :class:`~ost.mol.EntityView`/
+  :type ent:            :class:`~ost.mol.EntityView` /
                         :class:`~ost.mol.EntityHandle`
 
   :param probe_radius:  Radius of probe to determine accessible surface area
@@ -868,24 +913,18 @@ Algorithms on Structures
 
 
 
-
-
-
-
-
-
 .. _traj-analysis:
 
 Trajectory Analysis
 --------------------------------------------------------------------------------
 
-This is a set of functions used for basic trajectory analysis such as extracting 
-positions, distances, angles and RMSDs. The organization is such that most 
-functions have their counterpart at the individual :class:`frame level 
-<ost.mol.CoordFrame>` so that they can also be called on one frame instead 
-of the whole trajectory.
+This is a set of functions used for basic trajectory analysis such as extracting
+positions, distances, angles and RMSDs. The organization is such that most
+functions have their counterpart at the individual :class:`frame level
+<ost.mol.CoordFrame>` so that they can also be called on one frame instead of
+the whole trajectory.
 
-All these functions have a "stride" argument that defaults to stride=1, which is 
+All these functions have a "stride" argument that defaults to stride=1, which is
 used to skip frames in the analysis.
 
 
@@ -1024,11 +1063,11 @@ used to skip frames in the analysis.
  
   .. code-block:: python
      
-    eh=io.LoadPDB(...)
-    t=io.LoadCHARMMTraj(eh,...)
-    sele=eh.Select(...)
+    eh = io.LoadPDB(...)
+    t = io.LoadCHARMMTraj(eh, ...)
+    sele = eh.Select(...)
     t.CopyFrame(0)
-    mol.alg.AnalyzeRMSD(t,sele,sele)
+    mol.alg.AnalyzeRMSD(t, sele, sele)
 
   :param traj: The trajectory to be analyzed.
   :type traj: :class:`~ost.mol.CoordGroupHandle`
@@ -1086,21 +1125,20 @@ used to skip frames in the analysis.
      consecutive frames analyzed.  
 
 
-:mod:`mol.alg.helix_kinks <ost.mol.alg.helix_kinks>` -- Algorithms to calculate Helix Kinks
-================================================================================================
+:mod:`helix_kinks <ost.mol.alg.helix_kinks>` -- Algorithms to calculate Helix Kinks
+---------------------------------------------------------------------------------------------------------------
 
-.. autofunction:: ost.mol.alg.helix_kinks.CalculateHelixKink
-
-.. autofunction:: ost.mol.alg.helix_kinks.AnalyzeHelixKink
+.. automodule:: ost.mol.alg.helix_kinks
+   :members:
 
-:mod:`mol.alg.trajectory_analysis <ost.mol.alg.trajectory_analysis>` -- DRMSD, pairwise distances and more
-=============================================================================================================
+:mod:`trajectory_analysis <ost.mol.alg.trajectory_analysis>` -- DRMSD, pairwise distances and more
+---------------------------------------------------------------------------------------------------------------
 
 .. automodule:: ost.mol.alg.trajectory_analysis
    :members:
 
-:mod:`mol.alg.structure_analysis <ost.mol.alg.trajectory_analysis>` -- Functions to analyze structures
-=============================================================================================================
+:mod:`structure_analysis <ost.mol.alg.structure_analysis>` -- Functions to analyze structures
+---------------------------------------------------------------------------------------------------------------
 
 .. automodule:: ost.mol.alg.structure_analysis
    :members:
diff --git a/modules/mol/alg/pymod/helix_kinks.py b/modules/mol/alg/pymod/helix_kinks.py
index 3a45a20dc0264e56ef83a7177d7ad344ddd73fb2..3bfb86047ef167f3824b6f1e4e78c75e7f374f52 100644
--- a/modules/mol/alg/pymod/helix_kinks.py
+++ b/modules/mol/alg/pymod/helix_kinks.py
@@ -1,5 +1,5 @@
 """
-Functions to calculate helix kinks: bend, face shift and wobbla angles
+Functions to calculate helix kinks: bend, face shift and wobble angles
 
 Author: Niklaus Johner
 """
@@ -73,20 +73,21 @@ def __CalculateFaceShift(pre_proline_axis,post_proline_axis,pre_proline_centers,
   return sign*ost.geom.Angle(n1,n2)
 
 
-def AnalyzeHelixKink(t,sele,proline=False):
+def AnalyzeHelixKink(t, sele, proline=False):
   """
-  This function calculates the bend,wobble and face-shift angles
-  in an alpha-helix over a trajectory. The determination is more stable if
-  there are at least 4 residues on each side (8 is even better) of the proline around which
+  This function calculates the bend, wobble and face-shift angles in an alpha-
+  helix over a trajectory. The determination is more stable if there are at
+  least 4 residues on each side (8 is even better) of the proline around which
   the helix is kinked. The selection should contain all residues in the correct
   order and with no gaps and no missing C-alphas.
-  
+
   :param t: The trajectory to be analyzed
-  :type t: `~ost.mol.CoordGroup`
+  :type t: :class:`~ost.mol.CoordGroup`
   :param sele: A selection containing the alpha helix to be analyzed
   :type sele: :class:`~ost.mol.EntityView`
-  :param proline=False: A selection containing only the proline (or another residue) around 
-   which the helix is kinked. If False, the proline will be serached for automatically
+  :param proline: A selection containing only the proline (or another residue)
+                  around which the helix is kinked. If False, the proline will
+                  be searched for automatically
   :type proline: :class:`ost.mol.EntityView`
 
   :return: A tuple (bend_angle, face_shift, wobble_angle).
@@ -118,19 +119,20 @@ def AnalyzeHelixKink(t,sele,proline=False):
   return (bend_angle,face_shift,wobble_angle)
 
 
-def CalculateHelixKink(sele,proline=False):
+def CalculateHelixKink(sele, proline=False):
   """
-  This function calculates the bend,wobble and face-shift angles
-  in an alpha-helix of an EntityView. The determination is more stable if
-  there are at least 4 residues on each side (8 is even better) of the prolin around which
-  the helix is kinked. The selection should contain all residues in the correct
+  This function calculates the bend, wobble and face-shift angles in an alpha-
+  helix of an EntityView. The determination is more stable if there are at least
+  4 residues on each side (8 is even better) of the proline around which the
+  helix is kinked. The selection should contain all residues in the correct
   order and with no gaps and no missing C-alphas.
   
   :param sele: A selection containing the alpha helix to be analyzed
-  :type sele: :class:`~ost.mol.EntityView`
-  :param proline=False: A selection containing only the proline (or another residue) around 
-   which the helix is kinked. If False, the proline will be serached for automatically
-  :type proline: :class:`ost.mol.EntityView`
+  :type sele:  :class:`~ost.mol.EntityView`
+  :param proline: A selection containing only the proline (or another residue)
+                  around which the helix is kinked. If False, the proline will
+                  be searched for automatically
+  :type proline:  :class:`ost.mol.EntityView`
 
   :return: A tuple (bend_angle, face_shift, wobble_angle).
   :rtype: (float, float, float)